(* ------------------------------------------------------------------------------
 Using TIEGdiPlus
 For A Programmers Introduction To Using ImageEn Library Suite
 Copyright  1986-2013 : Adirondack Software & Graphics
 Last Modification     : 23-22-2013
 Description           : NewImage Unit
 Compiler              : Delphi XE4
 Operating System      : Windows 8.1
 This file is copyright  W W Miller, 1986-2013.
 It may be used without restriction. This code distributed on an "AS IS"
 basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.
 ------------------------------------------------------------------------------ *)

unit uNewImage;
{$WARN SYMBOL_PLATFORM OFF}
{$WARN UNIT_PLATFORM OFF}
interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls,
  Buttons, ExtCtrls, ComCtrls, Dialogs, ImageEnIO;

type
  TFormNewImage = class(TForm)
    GroupBox1: TGroupBox;
    RadioGroup1: TRadioGroup;
    RadioButton1: TRadioButton;
    RadioButton2: TRadioButton;
    RadioButton3: TRadioButton;
    RadioButton4: TRadioButton;
    Label1: TLabel;
    RadioButton5: TRadioButton;
    RadioButton6: TRadioButton;
    RadioButton7: TRadioButton;
    Panel1: TPanel;
    OKBtn: TButton;
    CancelBtn: TButton;
    GroupBox3: TGroupBox;
    Button1: TButton;
    ColorDialog1: TColorDialog;
    RadioButton8: TRadioButton;
    Label2: TLabel;
    GroupBox4: TGroupBox;
    FileType1: TComboBox;
    Shape1: TShape;
    Width1: TEdit;
    UpDown1: TUpDown;
    Height1: TEdit;
    UpDown2: TUpDown;
    procedure RadioButton4Click(Sender: TObject);
    procedure RadioButton1Click(Sender: TObject);
    procedure RadioButton2Click(Sender: TObject);
    procedure RadioButton3Click(Sender: TObject);
    procedure OKBtnClick(Sender: TObject);
    procedure RadioButton5Click(Sender: TObject);
    procedure RadioButton6Click(Sender: TObject);
    procedure RadioButton7Click(Sender: TObject);
    procedure RadioGroup1Click(Sender: TObject);
    procedure FileType1Change(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Button1Click(Sender: TObject);
  private
    procedure GetImageDescription;
    procedure GetFileType;
    procedure GetPixelFormat;
    procedure GetColor;
    procedure GetImageDimensions;
    procedure SetBitsPerSample(Value: integer);
    procedure SetSamplesPerPixel(Value: integer);
    procedure SetImageWidth(Value: integer);
    procedure SetImageHeight(Value: integer);
    procedure SetPixelFormat(Value: TPixelFormat);
    procedure SetColor(Value: TColor);
    procedure SetFileType(Value: TIOFileType);
    procedure SetFileTypeString(Value: string);
    procedure SetExtension(Value: string);
    procedure GetFileTypeString;
    procedure GetExtension;
    { Private declarations }
  public
    { Public declarations }
    fImageWidth: integer;
    fImageHeight: integer;
    fPixelFormat: TPixelFormat;
    fColor: TColor;
    fExtension: string;
    fFileType: TIOFileType;
    fFileTypeString: string;
    fBitsPerSample: integer;
    fSamplesPerPixel: integer;
    property BitsPerSample: integer read fBitsPerSample write SetBitsPerSample;
    property SamplesPerPixel: integer read fSamplesPerPixel write SetSamplesPerPixel;
    property ImageWidth: integer read fImageWidth write SetImageWidth;
    property ImageHeight: integer read fImageHeight write SetImageHeight;
    property PixelFormat: TPixelFormat read fPixelFormat write SetPixelFormat;
    property Color: TColor read fColor write SetColor;
    property FileType: TIOFileType read fFileType write SetFileType;
    property FileTypeString: string read fFileTypeString write SetFileTypeString;
    property Extension: string read fExtension write SetExtension;
  end;

var
  FormNewImage: TFormNewImage;

implementation

uses StrUtils, UITypes;
{$R *.dfm}

function IEFileTypeToExtension(AIEFileType: TIOFileType): string;
//Convert AIEFileType to a file extension
begin
  case AIEFileType of
    ioTIFF: Result := '.tif';
    ioGIF: Result := '.gif';
    ioJPEG: Result := '.jpg';
    ioPCX: Result := '.pcx';
    ioBMP: Result := '.bmp';
    ioICO: Result := '.ico';
    ioCUR: Result := '.cur';
    ioPNG: Result := '.png';
    ioWMF: Result := '.wmf';
    ioEMF: Result := '.emf';
    ioTGA: Result := '.tga';
    ioPXM: Result := '.ppm';
    ioJP2: Result := '.jp2';
    ioJ2K: Result := '.j2k';
    ioAVI: Result := '.avi';
    ioWBMP: Result := '.wbmp';
    ioPS: Result := '.ps';
    ioPDF: Result := '.pdf';
    ioDCX: Result := '.dcx';
    ioRAW: Result := '.raw';
    ioBMPRAW: Result := '.braw';
    ioWMV: Result := '.wmv';
    ioMPEG: Result := '.mpeg';
    ioPSD: Result := '.psd';
    ioIEV: Result := '.iev';
    ioHDP: Result := '.wdp';
    ioLYR: Result := '.lyr';
    ioALL: Result := '.all';
    ioDICOM: Result := '.dcm';
  end;
end;

function IEFileTypeToFileTypeString(AIEFileType: TIOFileType): string;
//Convert AIEFileType to a file type string
begin
  case AIEFileType of
    ioTIFF: Result := 'TIFF Bitmap';
    ioGIF: Result := 'GIF';
    ioJPEG: Result := 'Jpeg bitmap';
    ioPCX: Result := 'PaintBrush PCX';
    ioBMP: Result := 'Windows Bitmap';
    ioICO: Result := 'Windows Icon';
    ioCUR: Result := 'Windows Cursor';
    ioPNG: Result := 'Portable Network Graphics';
    ioWMF: Result := 'Windows Metafile';
    ioEMF: Result := 'Enhanced Windows Metafile';
    ioTGA: Result := 'Targa Bitmap';
    ioPXM: Result := 'Portable Pixmap, GreyMap, BitMap';
    ioJP2: Result := 'Jpeg2000';
    ioJ2K: Result := 'Jpeg2000';
    ioAVI: Result := 'AVI video';
    ioWBMP: Result := 'Wireless bitmap';
    ioPS: Result := 'Postscript';
    ioPDF: Result := 'Adobe PDF';
    ioDCX: Result := 'Multipage PCX';
    ioRAW: Result := 'Digital Camera RAW';
    ioBMPRAW: Result := 'Bitmap RAW';
    ioWMV: Result := 'Windows Media';
    ioMPEG: Result := 'Video MPEG';
    ioPSD: Result := 'Adobe Photoshop PSD';
    ioIEV: Result := 'Vectorial objects';
    ioLYR: Result := 'Layers';
    ioALL: Result := '>Combined layers and vectorial objects';
    ioDICOM: Result := 'DICOM medical imaging';
    ioHDP: Result := 'Microsoft HD Photo. Requires Windows XP (SP2) with .Net 3.0, Windows Vista';
    ioUSER: Result := 'User registered file formats';
  end;
end;

function ColorToPrettyName(const AColor: TColor): string;
{ Return a string of a TColor }
var
  ic: string;
begin
  result := '';
  ic := ColorToString(AColor);
  if AnsiContainsText(ic, 'cl') then
    Delete(ic, 1, 2);
  result := ic;
end;

procedure TFormNewImage.SetFileType(Value: TIOFileType);
begin
  if Value <> fFileType then
    fFileType := Value;
end;

procedure TFormNewImage.SetFileTypeString(Value: string);
begin
   if Value <> fFileTypeString then
   fFileTypeString := Value;
end;

procedure TFormNewImage.SetColor(Value: TColor);
begin
  if Value <> fColor then
    fColor := Value;
end;

procedure TFormNewImage.SetExtension(Value: string);
begin
  if Value <> fExtension then
    fExtension := Value;
end;

procedure TFormNewImage.SetPixelFormat(Value: TPixelFormat);
begin
  if Value <> fPixelFormat then
    fPixelFormat := Value;
end;

procedure TFormNewImage.SetImageHeight(Value: integer);
begin
  if Value <> fImageHeight then
    fImageHeight := Value;
end;

procedure TFormNewImage.SetImageWidth(Value: integer);
begin
  if Value <> fImageWidth then
    fImageWidth := Value;
end;

procedure TFormNewImage.SetBitsPerSample(Value: integer);
begin
  if Value <> fBitsPerSample then
    fBitsPerSample := Value;
end;

procedure TFormNewImage.SetSamplesPerPixel(Value: integer);
begin
  if Value <> fSamplesPerPixel then
    fSamplesPerPixel := Value;
end;

procedure TFormNewImage.RadioButton1Click(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.RadioButton2Click(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.RadioButton3Click(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.RadioButton4Click(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.RadioButton5Click(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.RadioButton6Click(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.RadioButton7Click(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.RadioGroup1Click(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.Button1Click(Sender: TObject);
begin
  ColorDialog1.Color := Shape1.Brush.Color;
  if ColorDialog1.Execute then
  begin
    Shape1.Brush.Color := ColorDialog1.Color;
    fColor := Shape1.Brush.Color;
    GetFileType;
    GetFileTypeString;
    GetPixelFormat;
    GetColor;
    GetImageDimensions;
    GetImageDescription;
  end;
end;

procedure TFormNewImage.FileType1Change(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
end;

procedure TFormNewImage.FormCreate(Sender: TObject);
begin
  fImageWidth := 16;
  fImageHeight := 16;
  fPixelFormat := pf24bit;
  fColor := clWhite;
  fFileType := ioPNG;
  fFileTypeString := IEFileTypeToFileTypeString(fFileType);
  fExtension := '.png';
end;

procedure TformNewImage.GetPixelFormat;
begin
  case RadioGroup1.ItemIndex of
    0:
      fPixelFormat := pf32bit;
    1:
      fPixelFormat := pf24bit;
    2:
      fPixelFormat := pf8bit;
    3:
      fPixelFormat := pf4bit;
    4:
      fPixelFormat := pf4bit;
  end;
end;

procedure TFormNewImage.GetColor;
begin
  fColor := Shape1.Brush.Color;
end;

procedure TFormNewImage.GetImageDimensions;
begin
  if RadioButton1.Checked then
  begin
    fImageWidth := 16;
    fImageHeight := 16;
    Width1.Enabled := false;
    Height1.Enabled := false;
  end
  else if RadioButton2.Checked then
  begin
    fImageWidth := 32;
    fImageHeight := 32;
    Width1.Enabled := false;
    Height1.Enabled := false;
  end
  else if RadioButton3.Checked then
  begin
    fImageWidth := 48;
    fImageHeight := 48;
    Width1.Enabled := false;
    Height1.Enabled := false;
  end
  else if RadioButton4.Checked then
  begin
    fImageWidth := 64;
    fImageHeight := 64;
    Width1.Enabled := true;
    Height1.Enabled := true;
  end
  else if RadioButton5.Checked then
  begin
    fImageWidth := 72;
    fImageHeight := 72;
    Width1.Enabled := false;
    Height1.Enabled := false;
  end
  else if RadioButton6.Checked then
  begin
    fImageWidth := 128;
    fImageHeight := 128;
    Width1.Enabled := false;
    Height1.Enabled := false;
  end
  else if RadioButton7.Checked then
  begin
    fImageWidth := StrToInt(Width1.Text);
    fImageHeight := StrToInt(Height1.Text);
    Width1.Enabled := true;
    Height1.Enabled := true;
  end
  else if RadioButton8.Checked then
  begin
    fImageWidth := Screen.Width;
    fImageHeight := Screen.Height;
    Width1.Enabled := true;
    Height1.Enabled := true;
  end;
end;

procedure TFormNewImage.GetImageDescription;
begin
  case RadioGroup1.ItemIndex of
    0:
      begin
        Label2.Caption := '24-bit with alpha channel ' + fFileTypeString + ' ' + IntToStr(fImageWidth) + ' x ' +
          IntToStr(fImageHeight)
          + ' pixels ' + ColorToPrettyName(fColor);
        Label2.Invalidate;
      end;
    1:
      begin
        Label2.Caption := '24-bit (16 million colors) ' + fFileTypeString + ' ' + IntToStr(fImageWidth) + ' x ' +
          IntToStr(fImageHeight)
          + ' pixels ' + ColorToPrettyName(fColor);
        Label2.Invalidate;
      end;
    2:
      begin
        Label2.Caption := '8-bit (256 colors) ' + fFileTypeString + ' ' + IntToStr(fImageWidth) + ' x ' + IntToStr(
          fImageHeight)
          + ' pixels ' + ColorToPrettyName(fColor);
        Label2.Invalidate;
      end;
    3:
      begin
        Label2.Caption := '4-bit (16 colors) ' + fFileTypeString + ' ' + IntToStr(fImageWidth) + ' x ' + IntToStr(
          fImageHeight)
          + ' pixels ' + ColorToPrettyName(fColor);
        Label2.Invalidate;
      end;
    4:
      begin
        Label2.Caption := '1-bit (Monochrome) ' + fFileTypeString + ' ' + IntToStr(fImageWidth) + ' x ' + IntToStr(
          fImageHeight)
          + ' pixels ' + ColorToPrettyName(fColor);
        Label2.Invalidate;
      end;
  end;
end;

procedure TFormNewImage.GetFileType;
begin
  case FileType1.ItemIndex of
    0:
      fFileType := ioTIFF;
    1:
      fFileType := ioGIF;
    2:
      fFileType := ioJPEG;
    3:
      fFileType := ioPCX;
    4:
      fFileType := ioBMP;
    5:
      fFileType := ioICO;
    6:
      fFileType := ioCUR;
    7:
      fFileType := ioPNG;
    8:
      fFileType := ioWMF;
    9:
      fFileType := ioEMF;
    10:
      fFileType := ioTGA;
    11:
      fFileType := ioPXM;
    12:
      fFileType := ioJP2;
    13:
      fFileType := ioJ2K;
    14:
      fFileType := ioAVI;
    15:
      fFileType := ioWBMP;
    16:
      fFileType := ioPS;
    17:
      fFileType := ioPDF;
    18:
      fFileType := ioPCX;
    19:
      fFileType := ioRAW;
    20:
      fFileType := ioBMPRAW;
    21:
      fFileType := ioWMV;
    22:
      fFileType := ioMPEG;
    23:
      fFileType := ioPSD;
    24:
      fFileType := ioIEV;
    25:
      fFileType := ioLYR;
    26:
      fFileType := ioALL;
    27:
      fFileType := ioDICOM;
    28:
      fFileType := ioHDP;
    29:
      fFileType := ioUSER;
  end;
end;

procedure TFormNewImage.GetFileTypeString;
begin
  fFileTypeString := IEFileTypeToFileTypeString(fFileType);
end;

procedure TFormNewImage.GetExtension;
begin
  fExtension := IEFileTypeToExtension(fFileType);
end;

procedure TFormNewImage.OKBtnClick(Sender: TObject);
begin
  GetFileType;
  GetFileTypeString;
  GetExtension;
  GetPixelFormat;
  GetColor;
  GetImageDimensions;
  GetImageDescription;
  SetImageWidth(fImageWidth);
  SetImageHeight(fImageHeight);
  SetPixelFormat(fPixelFormat);
  SetColor(fColor);
  SetFileType(fFileType);
  SetFileTypeString(fFileTypeString);
  SetExtension(fExtension);
end;

end.

